<?php

namespace B2buy\SupplierMaster\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use B2buy\SupplierMaster\Http\Requests\SupplierMasterRequest;
use B2buy\SupplierMaster\Interfaces\SupplierMasterRepositoryInterface;
use B2buy\SupplierMaster\Models\SupplierMaster;

/**
 * Resource controller class for supplier_master.
 */
class SupplierMasterResourceController extends BaseController
{

    /**
     * Initialize supplier_master resource controller.
     *
     * @param type SupplierMasterRepositoryInterface $supplier_master
     *
     * @return null
     */
    public function __construct(SupplierMasterRepositoryInterface $supplier_master)
    {
        parent::__construct();
        $this->repository = $supplier_master;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\SupplierMaster\Repositories\Criteria\SupplierMasterResourceCriteria::class);
    }

    /**
     * Display a list of supplier_master.
     *
     * @return Response
     */
    public function index(SupplierMasterRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\B2buy\SupplierMaster\Repositories\Presenter\SupplierMasterPresenter::class)
                ->$function();
        }

        $supplier_masters = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('supplier_master::supplier_master.names'))
            ->view('supplier_master::supplier_master.index', true)
            ->data(compact('supplier_masters', 'view'))
            ->output();
    }

    /**
     * Display supplier_master.
     *
     * @param Request $request
     * @param Model   $supplier_master
     *
     * @return Response
     */
    public function show(SupplierMasterRequest $request, SupplierMaster $supplier_master)
    {

        if ($supplier_master->exists) {
            $view = 'supplier_master::supplier_master.show';
        } else {
            $view = 'supplier_master::supplier_master.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('supplier_master::supplier_master.name'))
            ->data(compact('supplier_master'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new supplier_master.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(SupplierMasterRequest $request)
    {

        $supplier_master = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('supplier_master::supplier_master.name')) 
            ->view('supplier_master::supplier_master.create', true) 
            ->data(compact('supplier_master'))
            ->output();
    }

    /**
     * Create new supplier_master.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SupplierMasterRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $supplier_master                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('supplier_master::supplier_master.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('supplier_master/supplier_master/' . $supplier_master->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/supplier_master/supplier_master'))
                ->redirect();
        }

    }

    /**
     * Show supplier_master for editing.
     *
     * @param Request $request
     * @param Model   $supplier_master
     *
     * @return Response
     */
    public function edit(SupplierMasterRequest $request, SupplierMaster $supplier_master)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('supplier_master::supplier_master.name'))
            ->view('supplier_master::supplier_master.edit', true)
            ->data(compact('supplier_master'))
            ->output();
    }

    /**
     * Update the supplier_master.
     *
     * @param Request $request
     * @param Model   $supplier_master
     *
     * @return Response
     */
    public function update(SupplierMasterRequest $request, SupplierMaster $supplier_master)
    {
        try {
            $attributes = $request->all();

            $supplier_master->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('supplier_master::supplier_master.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('supplier_master/supplier_master/' . $supplier_master->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('supplier_master/supplier_master/' . $supplier_master->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the supplier_master.
     *
     * @param Model   $supplier_master
     *
     * @return Response
     */
    public function destroy(SupplierMasterRequest $request, SupplierMaster $supplier_master)
    {
        try {

            $supplier_master->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('supplier_master::supplier_master.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('supplier_master/supplier_master/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('supplier_master/supplier_master/' . $supplier_master->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple supplier_master.
     *
     * @param Model   $supplier_master
     *
     * @return Response
     */
    public function delete(SupplierMasterRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('supplier_master::supplier_master.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('supplier_master/supplier_master'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/supplier_master/supplier_master'))
                ->redirect();
        }

    }

    /**
     * Restore deleted supplier_masters.
     *
     * @param Model   $supplier_master
     *
     * @return Response
     */
    public function restore(SupplierMasterRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('supplier_master::supplier_master.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/supplier_master/supplier_master'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/supplier_master/supplier_master/'))
                ->redirect();
        }

    }

}
